@@ -6,9 +6,9 @@ module OmniAuth
       option :name, 'alicloud'
 
       option :client_options, {
-        :site => 'https://oauth.aliyun.com/',
-        :authorize_url => 'https://signin.aliyun.com/oauth2/v1/auth',
-        :token_url => 'https://oauth.aliyun.com/v1/token'
+        site: 'https://oauth.aliyun.com/',
+        authorize_url: 'https://signin.aliyun.com/oauth2/v1/auth',
+        token_url: 'https://oauth.aliyun.com/v1/token'
       }
 
       uid do
@@ -35,10 +35,6 @@ module OmniAuth
       def raw_info
         @raw_info ||= access_token.get('/v1/userinfo').parsed || {}
       end
-
-      def callback_url
-        full_host + script_name + callback_path
-      end
     end
   end
 end
